package com.ruoyi.demo.controller;

import com.ruoyi.common.core.domain.R;
import com.ruoyi.demo.entity.*;
import com.ruoyi.demo.entity.vo.WdInfoVo;
import com.ruoyi.demo.service.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;

/**
 * 精准营销管理中心——数据回收站
 */
@RestController
@RequestMapping("/recycle/wd")
public class WdRecycleController {


    @Autowired
    WdRecycleService wdRecycleService;

    @Autowired
    StoreWdService storeWdService;

    @Autowired
    HouseWdService houseWdService;

    @Autowired
    BuildWdService buildWdService;

    @Autowired
    TrafficWdService trafficWdService;

    @Autowired
    EnterpriseWdService enterpriseWdService;


    /**
     * 获取网点回收站列表
     * @param wdInfoVo 网点信息接受体
     * @return
     */
    @GetMapping("/list")
    public R list(WdInfoVo wdInfoVo){
        HashMap<String, Object> list = wdRecycleService.list(wdInfoVo);
        return R.ok(list);
    }

    /**
     * 获取门店网点类型明细
     * @param wdId 网点Id
     * @return
     */
    @GetMapping("/storeWdInfo")
    public R storeWdInfo(String wdId){
        StoreWd storeWd = storeWdService.storeWdInfo(wdId);
        return R.ok(storeWd);
    }

    /**
     * 获取小区网点类型明细
     * @param wdId 网点Id
     * @return
     */
    @GetMapping("/houseWdInfo")
    public R houseWddInfo(String wdId){
        HouseWd houseWd = houseWdService.houseWddInfo(wdId);
        return R.ok(houseWd);
    }

    /**
     * 获取楼宇网点类型明细
     * @param wdId 网点Id
     * @return
     */
    @GetMapping("/buildWdInfo")
    public R buildWdInfo(String wdId){
        BuildWd buildWd = buildWdService.buildWdInfo(wdId);
        return R.ok(buildWd);
    }

    /**
     * 获取交通设施网点类型明细
     * @param wdId 网点Id
     * @return
     */
    @GetMapping("/trafficWdInfo")
    public R trafficWdInfo(String wdId){
        TrafficWd trafficWd = trafficWdService.trafficWdInfo(wdId);
        return R.ok(trafficWd);
    }

    /**
     * 获取公司网点类型明细
     * @param wdId 网点Id
     * @return
     */
    @GetMapping("/enterpriseWdInfo")
    public R enterpriseWdInfo(String wdId){
        EnterpriseWd enterpriseWd = enterpriseWdService.enterpriseWdInfo(wdId);
        return R.ok(enterpriseWd);
    }

    /**
     * 移除网点
     * @param wdId 网点Id
     * @return
     */
    @DeleteMapping("/deleteWd/{wdId}")
    public R deleteWd(@PathVariable("wdId") String wdId){
        wdRecycleService.deleteWd(wdId);
        return R.ok();
    }

    /**
     * 恢复网点
     * @param wdInfoVo
     * @return
     */
    @PutMapping("/recoverWd")
    public R recoverWd(@RequestBody WdInfoVo wdInfoVo){
        if (wdInfoVo.getWdId() == null)
            return R.fail(400,"wdId不能为空");

        wdRecycleService.recoverWd(wdInfoVo.getWdId());
        return R.ok();
    }

}
